==> FHLBBS-4.8.tgz: wbbs/edit.c <==
#include "cgic.h"
#include "wbbs.c"

struct fileheader replyfile;
struct stat st;
int currmode;
int cgiMain() {
FILE *fptr1,*fptr2;
char title1[70],comment1[MAXLEN+1],date1[10],buf1[100];
char filename1[70],filename2[30],divide[100], oneline[301];
char linetwo[301];
time_t t1;
int len1, fd, numposts, numarticle;
int editmode;//0=post 1=reply 2= replay to auther 3=mail 4=reply mail  
boardheader *bp;
boardheader *getbcache();
char *bdname,buf2[100];
int ptmode;
char *pt1,*pt2;
int sign=0,i;

	cgiFormString("board1", currboard, IDLEN+1);
    /*** NƶǶicookie **/
    if(!check_passwd()) return(0);
    Cookienumin=Cookienumout;    
    if (currboard[0]==0) 
    {
	 strcpy(currboard,Cboardout);
     strcpy(Cboardin,Cboardout);
    }
    else strcpy(Cboardin,currboard);

    if(!check_passwd()) return(0);

    if (strrchr(currboard,'/')) //ȬOhacker
    {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
    }
	bdname=currboard;
	strncpy(divide,getenv("QUERY_STRING"),99);
	divide[99]=0;
    strcpy(title1,"");
	if(strstr(divide,"reply") != NULL)
	  {
       editmode=1;
      }
      else if (strstr(divide,"remail")!=NULL)
      {
        editmode=4;
      }
	else if (strstr(divide,"mail")!=NULL)
      {
        editmode=3;
	if (strcmp(cuser.userid,"guest")==0)
	{
            cgiHeaderContentType("text/html");
            fprintf(cgiOut,"GuestSHHvQI<p>\n");
            return(0);
	}
      }
    else if (strstr(divide,"reauth")!=NULL)
      {
        editmode=2;
      }
    else
	  {
        editmode=0;
      }

    /*** QװϬ ***/
	if (editmode < 3)
	{
          bp = getbcache(bdname);
          if ((!bp)||(!Ben_Perm(bp)))
          {
            cgiHeaderContentType("text/html");
            fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
            return(0);
	      }
          if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM(bp->BM)))
          {
             currmode |= (MODE_BOARD | MODE_POST);
          }
          else if (haspostperm(bdname)) currmode |= MODE_POST;
          if ((!((currmode)&(MODE_POST)))&&(editmode<2))
	  {
	     if (strcmp(cuser.userid,"guest")==0)
	      {
		cook_buf[83]=0;
     		fprintf(cgiOut,"Set-Cookie: bbs=%-79s%s?%s; path=/\n",
		cook_buf+4,cgiScriptName,
		cgiQueryString); //ڳ]wcookie cook_buf+4 L bbs=
	    	cgiHeaderContentType("text/html");
	    	fprintf(cgiOut,"<script LANGUAGE=\"JavaScript\" FOR=\"window\" "
        	"EVENT=\"onload()\">\n"
	    	"<!--\n"
        	"window.location=\"%s\""
	    	"\n//-->\n</script>\n",LOGINWIN);
	      }
	    else //not guest 
	    {
	        cgiHeaderContentType("text/html");
	        fprintf(cgiOut,"藍_AzثeLkbo峹I<p>\n");
	        return(0);
	    }
	  }
	}
	cgiHeaderContentType("text/html");
   
   sprintf(buf2, "%s%s",DEFDIR,prefile[editmode]);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
   }
   else
   {
   while (fgets(oneline,300,fptr2))
   {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
             /**** ^Ҧ *************/
      	  if ((editmode==1)||(editmode==2)||(editmode==4)) 
          {
	        if ((editmode==1)||(editmode==2))
	          sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
	        else
	          sprintf(buf1,BBSHOME "/home/%s/.DIR", cuser.userid);
	        if( stat(buf1, &st ) >= 0 )
	          numposts = st.st_size / (sizeof( struct fileheader ));
	        else   numposts = 0;
            /*** ɮ׽sѼƧѼơA_hCookie ***/
            cgiFormIntegerBounded("numarticle",&numarticle,1,numposts,Cookienumout);
            fd = open(buf1,O_RDONLY );
	        lseek(fd, sizeof(replyfile)*(numarticle-1), SEEK_SET);
	        read(fd,&replyfile,sizeof(replyfile));
	        close(fd);
	        if(strncmp(replyfile.title,"Re: ",4) == 0)
	          strcpy(title1,replyfile.title);
	        else
	          sprintf(title1,"Re: %s",replyfile.title);
	        sprintf(comment1, " ޭzm%snʨG\n", replyfile.owner);
	        if ((editmode==1)||(editmode==2))
	         sprintf(filename1, BBSHOME "/boards/%s/%s", 
             currboard, replyfile.filename);
	        else
	         sprintf(filename1, BBSHOME "/home/%s/%s",
	         cuser.userid,replyfile.filename);
           /****Bzި ***/
	        if((fptr1 = fopen(filename1, "r")) != NULL) 
            {
	          //while(fgets(linetwo, 300, fptr1) != NULL) 
	          //if(strlen(linetwo) < 2) break;
    	      linetwo[0] = ':';
	          linetwo[1] = ' ';
	          while(fgets(linetwo + 2, 290, fptr1) != NULL)  
              {
	           if(strncmp(linetwo + 2, "</pre><p></font>", 16) == 0) break;
               /* 屼ñW */
               if(strncmp(linetwo+2,"--",2)==0) break;
	           if(strlen(linetwo + 2) > 3)
	             strcat(comment1, linetwo);
	          }
 	          fclose(fptr1);
	        }
	      } // edit mode =1 ,2, 4
	    if (editmode<2)
	        fprintf(cgiOut,"zjW:%s<p>\n",cuser.userid);
	    else if ((editmode==4)||(editmode==2))
	    {
	     fprintf(cgiOut,"^HG%s<p>\n",replyfile.owner);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"RECEIVER\" "
         "value=\"%s\"><P>\n",replyfile.owner);
	    }
	    else  // edit mode = 3
        {
          cgiFormString("id", buf1, IDLEN+1);
          if (buf1[0]) /** idi **/
            fprintf(cgiOut,"HH:%s<input type=\"hidden\" name=\"RECEIVER\" "
           " value=\"%s\"><P>\n",buf1,buf1);
            
          else 
            fprintf(cgiOut,"HH:<input type=\"text\" name=\"RECEIVER\" "
         "size=12 maxlength=12><P>\n");
	       
        }
	    fprintf(cgiOut,"D:<input type=\"text\" name=\"title1\" "
        "size= %d maxlength= %d value=\"%s\"><P>\n",BTLEN,BTLEN,title1);
	   if((editmode==1)||(editmode==2)||(editmode==4)) 
       {
	     fprintf(cgiOut,"<input type=\"hidden\" "
         "name=\"replytitle\" value=\"%s\"><P>\n",replyfile.title);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"replyfilename\" "
        "value=\"%s\"><P>\n",replyfile.filename);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"numarticle\" "
         "value=\"%d\"><P>\n",numarticle);
	    }
	   if (editmode<3)
        {
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
         "value=\"%s\"><P>\n",currboard);
          fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
         "value=\"0\"><P>\n");
        }
	   else
        {
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
         "value=\"mail\">\n");
         fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
         "value=\"1\"><P>\n");
        }
       if (editmode<2) 
         fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
         "value=\"0\"><P>\n");
       else
         fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
         "value=\"1\"><P>\n");
       fprintf(cgiOut,"峹JϡG<br>\n");
	   fprintf(cgiOut,"<textarea name=\"comment1\" rows=15 cols=70"
         ">%s</textarea><p>\n", comment1);  
       /*** BzñW **/
       sign=(cuser.uflag & SIG_FLAG);
       if (sign==0)
         {
          fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"SIGNYN\""
            "checked>[ñW");
          fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"SIGNYN\""
            ">[ñW");
          fprintf(cgiOut," ϥñW<input type=\"text\" value=\"1\""
             " name=\"SIGNFILE\" size=2 maxlength=1>");
         }
        else
         {
          fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"SIGNYN\""
            ">[ñW");
          fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"SIGNYN\""
            "checked>[ñW");
          fprintf(cgiOut," ϥñW<input type=\"text\" value=\"%d\""
             " name=\"SIGNFILE\" size=2 maxlength=1 >",sign);
         }
       /*** BzHP_ ***/
       if (editmode<2)
       {
        fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"LOCALSAVE\""
           "checked>ѻPH");
         fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"LOCALSAVE\""
           ">峹");
       }
        /* show ñW 
        for (i=1;i<=10;i++)
        {
         sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,i);
         if (fptr1 = fopen(buf1, "r"))
         {
           fprintf(cgiOut,"<br>ñW %dG<hr><br>\n",i);
           pfile(fptr1);
           fclose(fptr1); 
         }
        }
	*******/
      } //ptmode
     else // other mode
            SSI(ptmode);
     } // while pt2=
     fprintf(cgiOut,"%s",pt1);   
   } //while get line

    fclose(fptr2);   
   }
	return 0;
}

==> FHLBBS-5.3.tgz: wbbs/edit.c <==
#include "cgic.h"
#include "wbbs.c"

struct fileheader replyfile;
struct stat st;
int currmode;
int cgiMain() {
FILE *fptr1,*fptr2;
char title1[70],comment1[MAXLEN+1],date1[10],buf1[100],showowner[IDLEN + 2];
char filename1[70],filename2[30],divide[100], oneline[301];
char linetwo[301];
time_t t1;
int len1, fd, numposts, numarticle;
int editmode;//0=post 1=reply 2= replay to auther 3=mail 4=reply mail  
boardheader *bp;
boardheader *getbcache();
char *bdname,buf2[100];
int ptmode;
char *pt1,*pt2;
int sign=0,i;

	cgiFormString("board1", currboard, IDLEN+1);
    /*** NƶǶicookie **/
    if(!check_passwd()) return(0);
    Cookienumin=Cookienumout;    
    if (currboard[0]==0) 
    {
	 strcpy(currboard,Cboardout);
     strcpy(Cboardin,Cboardout);
    }
    else strcpy(Cboardin,currboard);

    if(!check_passwd()) return(0);

    if (strrchr(currboard,'/')) //ȬOhacker
    {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
    }
	bdname=currboard;
	strncpy(divide,getenv("QUERY_STRING"),99);
	divide[99]=0;
    strcpy(title1,"");
	if(strstr(divide,"reply") != NULL)
	  {
       editmode=1;
      }
      else if (strstr(divide,"remail")!=NULL)
      {
        editmode=4;
      }
	else if (strstr(divide,"mail")!=NULL)
      {
        editmode=3;
	if (strcmp(cuser.userid,"guest")==0)
	{
            cgiHeaderContentType("text/html");
            fprintf(cgiOut,"GuestSHHvQI<p>\n");
            return(0);
	}
      }
    else if (strstr(divide,"reauth")!=NULL)
      {
        editmode=2;
      }
    else
	  {
        editmode=0;
      }

    /*** QװϬ ***/
	if (editmode < 3)
	{
          bp = getbcache(bdname);
          if ((!bp)||(!Ben_Perm(bp)))
          {
            cgiHeaderContentType("text/html");
            fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
            return(0);
	      }
          if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM(bp->BM)))
          {
             currmode |= (MODE_BOARD | MODE_POST);
          }
          else if (haspostperm(bdname)) currmode |= MODE_POST;
          if ((!((currmode)&(MODE_POST)))&&(editmode<2))
	  {
	     if (strcmp(cuser.userid,"guest")==0)
	      {
		authwin();
		return(0);
	      }
	    else //not guest 
	    {
	        cgiHeaderContentType("text/html");
	        fprintf(cgiOut,"藍_AzثeLkbo峹I<p>\n");
	        return(0);
	    }
	  }
	}
	cgiHeaderContentType("text/html");
   
   sprintf(buf2, "%s%s",DEFDIR[doorid],prefile[editmode]);
   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0;
   }
   else
   {
   while (fgets(oneline,300,fptr2))
   {
      pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
             /**** ^Ҧ *************/
      	  if ((editmode==1)||(editmode==2)||(editmode==4)) 
          {
	        if ((editmode==1)||(editmode==2))
	          sprintf(buf1,BBSHOME "/boards/%s/.DIR", currboard);
	        else
	          sprintf(buf1,BBSHOME "/home/%s/.DIR", cuser.userid);
	        if( stat(buf1, &st ) >= 0 )
	          numposts = st.st_size / (sizeof( struct fileheader ));
	        else   numposts = 0;
            /*** ɮ׽sѼƧѼơA_hCookie ***/
            cgiFormIntegerBounded("numarticle",&numarticle,1,numposts,Cookienumout);
            fd = open(buf1,O_RDONLY );
	        lseek(fd, sizeof(replyfile)*(numarticle-1), SEEK_SET);
	        read(fd,&replyfile,sizeof(replyfile));
	        close(fd);
	        if(strncmp(replyfile.title,"Re: ",4) == 0)
	          strcpy(title1,replyfile.title);
	        else
	          sprintf(title1,"Re: %s",replyfile.title);
		/*Bz comfortable **/
		if (((editmode==1)||(editmode==2))
  		  &&(strcmp(currboard,"comfortable")==0))
	          sprintf(comment1, " ޭzmanonymousnʨG\n");
		else 
	          sprintf(comment1, " ޭzm%snʨG\n", replyfile.owner);
	        if ((editmode==1)||(editmode==2))
	         sprintf(filename1, BBSHOME "/boards/%s/%s", 
             currboard, replyfile.filename);
	        else
	         sprintf(filename1, BBSHOME "/home/%s/%s",
	         cuser.userid,replyfile.filename);
           /****Bzި ***/
	        if((fptr1 = fopen(filename1, "r")) != NULL) 
            {
	          //while(fgets(linetwo, 300, fptr1) != NULL) 
	          //if(strlen(linetwo) < 2) break;
    	      linetwo[0] = ':';
	          linetwo[1] = ' ';
	          while(fgets(linetwo + 2, 290, fptr1) != NULL)  
              {
	           if(strncmp(linetwo + 2, "</pre><p></font>", 16) == 0) break;
               /* 屼ñW */
               if(strncmp(linetwo+2,"--",2)==0) break;
	           if(strlen(linetwo + 2) > 3)
	             strcat(comment1, linetwo);
	          }
 	          fclose(fptr1);
	        }
	      } // edit mode =1 ,2, 4
	    if (editmode<2)
	        fprintf(cgiOut,"zjW:%s<p>\n",cuser.userid);
	    else if ((editmode==4)||(editmode==2))
	    {
		if ((editmode==2)&&(strcmp(currboard,"comfortable")==0))
	     	  fprintf(cgiOut,"^HGanonymous<p>\n");
		else
	     	  fprintf(cgiOut,"^HG%s<p>\n",replyfile.owner);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"RECEIVER\" "
         "value=\"%s\"><P>\n",replyfile.owner);
	    }
	    else  // edit mode = 3
        {
          cgiFormString("id", buf1, IDLEN+1);
          if (buf1[0]) /** idi **/
            fprintf(cgiOut,"HH:%s<input type=\"hidden\" name=\"RECEIVER\" "
           " value=\"%s\"><P>\n",buf1,buf1);
            
          else 
            fprintf(cgiOut,"HH:<input type=\"text\" name=\"RECEIVER\" "
         "size=12 maxlength=12><P>\n");
	       
        }
	    fprintf(cgiOut,"D:<input type=\"text\" name=\"title1\" "
        "size= %d maxlength= %d value=\"%s\"><P>\n",BTLEN,BTLEN,title1);
	   if((editmode==1)||(editmode==2)||(editmode==4)) 
       {
	     fprintf(cgiOut,"<input type=\"hidden\" "
         "name=\"replytitle\" value=\"%s\"><P>\n",replyfile.title);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"replyfilename\" "
        "value=\"%s\"><P>\n",replyfile.filename);
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"numarticle\" "
         "value=\"%d\"><P>\n",numarticle);
	    }
	   if (editmode<3)
        {
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
         "value=\"%s\"><P>\n",currboard);
          fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
         "value=\"0\"><P>\n");
        }
	   else
        {
	     fprintf(cgiOut,"<input type=\"hidden\" name=\"board1\" "
         "value=\"mail\">\n");
         fprintf(cgiOut,"<input type=\"hidden\" name=\"WHERE\" "
         "value=\"1\"><P>\n");
        }
       if (editmode<2) 
         fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
         "value=\"0\"><P>\n");
       else
         fprintf(cgiOut,"<input type=\"hidden\" name=\"TARGET\" "
         "value=\"1\"><P>\n");
       fprintf(cgiOut,"峹JϡG<br>\n");
	   fprintf(cgiOut,"<textarea name=\"comment1\" rows=15 cols=70"
         ">%s</textarea><p>\n", comment1);  
       /*** BzñW **/
       sign=(cuser.uflag & SIG_FLAG);
       if (sign==0)
         {
          fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"SIGNYN\""
            "checked>[ñW");
          fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"SIGNYN\""
            ">[ñW");
          fprintf(cgiOut," ϥñW<input type=\"text\" value=\"1\""
             " name=\"SIGNFILE\" size=2 maxlength=1>");
         }
        else
         {
          fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"SIGNYN\""
            ">[ñW");
          fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"SIGNYN\""
            "checked>[ñW");
          fprintf(cgiOut," ϥñW<input type=\"text\" value=\"%d\""
             " name=\"SIGNFILE\" size=2 maxlength=1 >",sign);
         }
       /*** BzHP_ ***/
       if (editmode<2)
       {
        fprintf(cgiOut,"<input type=\"radio\" value=\"1\" name=\"LOCALSAVE\""
           "checked>ѻPH");
         fprintf(cgiOut,"<input type=\"radio\" value=\"0\" name=\"LOCALSAVE\""
           ">峹");
       }
        /* show ñW 
        for (i=1;i<=10;i++)
        {
         sprintf(buf1, BBSHOME "/home/%s/sig.%d", cuser.userid,i);
         if (fptr1 = fopen(buf1, "r"))
         {
           fprintf(cgiOut,"<br>ñW %dG<hr><br>\n",i);
           pfile(fptr1);
           fclose(fptr1); 
         }
        }
	*******/
      } //ptmode
     else // other mode
            SSI(ptmode);
     } // while pt2=
     fprintf(cgiOut,"%s",pt1);   
   } //while get line

    fclose(fptr2);   
   }
	return 0;
}
